Modules
- bloom
- Lightweight bloom-style filter used by segments to skip cold lookups.
- hot
- Lock-free hot index that keeps track of the latest versions per key.
- secondary
- Secondary index sidecars that enrich lookups beyond the primary key.
- sparse
- Sparse segment index for quickly narrowing down on-disk lookups.
Structs
- Version
Pointer - Pointer describing where a value for a key can be retrieved.
Enums
- Version
Location - Location variants for an indexed version.
Type Aliases
- Record
Id - Identifier of a record inside MindB.
- Sequence
Number - Sequence number attached to a version written by the MVCC machinery.